==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Archiveren',
	'archiver_concatener_explications' => 'Deze handeling voegt de bezoekstatistieken samen van de artikelen:',
	'archiver_concatener_ignorer' => 'Bezoeken onder @nb@ jaar worden niet meegenomen.',
	'archiver_concatener_par_an' => 'Bezoeken van meer dan @nb@ jaar geleden worden samengevoegd, per artikel, in de eerste dag van ieder jaar.',
	'archiver_concatener_par_mois' => 'Bezoeken van meer dan @nb@ jaar geleden worden samengevoegd, per artikel, in de eerste dag van iedere maand.',
	'archiver_conseil_sauvegarde' => 'Er wordt aangeraden om eerst een backup van de database te maken.',
	'archiver_description' => 'Deze bladzijde biedt tools om de statistieken van de site te archiveren en op te schonen.',
	'archiver_et_nettoyer' => 'Archiveren en opruimen',
	'archiver_nettoyer' => 'Opruimen',
	'archiver_nettoyer_explications' => 'Ruim referers of bezoekgegevens op van artikelen die niet (meer) in de database voorkomen.',
	'archiver_nettoyer_referers_articles' => 'Referers van artikelen opruimen',
	'archiver_nettoyer_visites_articles' => 'Bezoekgegevens van artikelen opruimen',
	'archiver_nombre_lignes' => 'Aantal regels',
	'archiver_operation_longue' => 'Deze handeling kan geruime tijd duren, met name de eerste keer.',
	'archiver_operations_irreversibles' => 'Deze handelingen zijn onomkeerbaar!',

	// B
	'bouton_effacer_referers' => 'Alleen binnenkomende links uitwissen',
	'bouton_effacer_statistiques' => 'De statistieken uitwissen',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evolutie van de bezoeken<br />@visites@ bezoeken',
	'icone_repartition_actuelle' => 'De huidige verdeling tonen',
	'icone_repartition_visites' => 'Verdeling van de bezoeken',
	'icone_statistiques_visites' => 'Statistieken',
	'info_affichier_visites_articles_plus_visites' => 'Bezoekers tonen voor <b>de meest bezochte artikelen sinds het begin:</b>',
	'info_comment_lire_tableau' => 'Hoe lees je deze tabel',
	'info_forum_statistiques' => 'Statistieken van de bezoeken',
	'info_graphiques' => 'Grafieken',
	'info_popularite_2' => 'populariteit van de site:',
	'info_popularite_3' => 'populariteit: @popularite@; bezoeken: @visites@',
	'info_popularite_5' => 'populariteit:',
	'info_previsions' => 'verwachting:',
	'info_question_vignettes_referer' => 'Wanneer je de statistieken raadpleegt, kun je korte overzichten van de plaatsen van oorsprong van de bezoeken zichtbaar maken wanneer <a href="@url@">de plugin Thumbsites</a> actief is.',
	'info_question_vignettes_referer_oui' => 'De site van waaraf het bezoek werd gedaan weergeven',
	'info_referer_oui' => 'De referers activeren',
	'info_tableaux' => 'Tabellen',
	'info_visites' => 'bezoeken:',
	'info_visites_plus_populaires' => 'Toon de bezoeken voor <b>de meest populaire artikelen</b> en voor <b>de laatst gepubliceerde artikelen:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Statistieken beheren',

	// M
	'moyenne' => 'Gemiddelde',

	// O
	'onglet_origine_visites' => 'Herkomst van de bezoeken',
	'onglet_repartition_debut' => 'vanaf het begin',
	'onglet_repartition_lang' => 'Verdeling volgens taal',

	// R
	'resume' => 'Samenvatting',

	// T
	'texte_admin_effacer_stats' => 'Deze opdracht wist alle statistische gegevens over bezoeken aan de site, met inbegrip van de populariteit van de artikelen.',
	'texte_admin_effacer_toutes_stats' => 'Het eerste knopje wist alle statistieken uit: bezoeken, populariteit van de artikelen en binnenkomende links.',
	'texte_comment_lire_tableau' => 'De plaats van het artikel, in de rangschikking volgens populariteit, is in de marge aangegeven; de populariteit (een schatting van het aantal bezoeken dat het artikel op een dag zal krijgen als het huidige ritme wordt aangehouden) en het aantal bezoeken sinds het het begin van de site staan in het vakje dat verschijnt als je met de muis over de titel van het artikel beweegt.',
	'texte_signification' => 'De donkere balkjes stellen alle samengetelde bezoeken weer (totaal van alle subrubrieken), de lichte balkjes het aantal bezoeken voor elke rubriek.',
	'titre_evolution_visite' => 'Evolutie van de bezoeken',
	'titre_liens_entrants' => 'Inkomende koppelingen',
	'titre_page_statistiques' => 'Statistieken per rubriek',
	'titre_page_statistiques_visites' => 'Statistieken van de bezoeken',

	// V
	'visites_journalieres' => 'Aantal bezoeken per dag',
	'visites_mensuelles' => 'Aantal maandelijkse bezoeken'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// A
	'archiver' => 'Archiveren',
	'archiver_concatener_explications' => 'Deze handeling voegt de bezoekstatistieken samen van de artikelen:',
	'archiver_concatener_ignorer' => 'Bezoeken onder @nb@ jaar worden niet meegenomen.',
	'archiver_concatener_par_an' => 'Bezoeken van meer dan @nb@ jaar geleden worden samengevoegd, per artikel, in de eerste dag van ieder jaar.',
	'archiver_concatener_par_mois' => 'Bezoeken van meer dan @nb@ jaar geleden worden samengevoegd, per artikel, in de eerste dag van iedere maand.',
	'archiver_et_nettoyer' => 'Archiveren en opruimen',
	'archiver_nettoyer' => 'Opruimen',
	'archiver_nettoyer_explications' => 'Ruim referers of bezoekgegevens op van artikelen die niet (meer) in de database voorkomen.',
	'archiver_nettoyer_referers_articles' => 'Referers van artikelen opruimen',
	'archiver_nettoyer_visites_articles' => 'Bezoekgegevens van artikelen opruimen',
	'archiver_nombre_lignes' => 'Aantal regels',
	'archiver_operation_longue' => 'Deze handeling kan geruime tijd duren, met name de eerste keer.',

	// B
	'bouton_effacer_referers' => 'Alleen binnenkomende links uitwissen',
	'bouton_effacer_statistiques' => 'De statistieken uitwissen',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evolutie van de bezoeken<br />@visites@ bezoeken',
	'icone_repartition_actuelle' => 'De huidige verdeling tonen',
	'icone_repartition_visites' => 'Verdeling van de bezoeken',
	'icone_statistiques_visites' => 'Statistieken',
	'info_affichier_visites_articles_plus_visites' => 'Bezoekers tonen voor <b>de meest bezochte artikelen sinds het begin:</b>',
	'info_comment_lire_tableau' => 'Hoe lees je deze tabel',
	'info_forum_statistiques' => 'Statistieken van de bezoeken',
	'info_graphiques' => 'Grafieken',
	'info_popularite_2' => 'populariteit van de site:',
	'info_popularite_3' => 'populariteit: @popularite@; bezoeken: @visites@',
	'info_popularite_5' => 'populariteit:',
	'info_previsions' => 'verwachting:',
	'info_question_vignettes_referer' => 'Wanneer je de statistieken raadpleegt, kun je korte overzichten van de plaatsen van oorsprong van de bezoeken zichtbaar maken wanneer <a href="@url@">de plugin Thumbsites</a> actief is.',
	'info_question_vignettes_referer_oui' => 'De site van waaraf het bezoek werd gedaan weergeven',
	'info_referer_oui' => 'De referers activeren',
	'info_tableaux' => 'Tabellen',
	'info_visites' => 'bezoeken:',
	'info_visites_plus_populaires' => 'Toon de bezoeken voor <b>de meest populaire artikelen</b> en voor <b>de laatst gepubliceerde artikelen:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Statistieken beheren',

	// M
	'moyenne' => 'Gemiddelde',

	// O
	'onglet_origine_visites' => 'Herkomst van de bezoeken',
	'onglet_repartition_debut' => 'vanaf het begin',
	'onglet_repartition_lang' => 'Verdeling volgens taal',

	// R
	'resume' => 'Samenvatting',

	// T
	'texte_admin_effacer_stats' => 'Deze opdracht wist alle statistische gegevens over bezoeken aan de site, met inbegrip van de populariteit van de artikelen.',
	'texte_admin_effacer_toutes_stats' => 'Het eerste knopje wist alle statistieken uit: bezoeken, populariteit van de artikelen en binnenkomende links.',
	'texte_comment_lire_tableau' => 'De plaats van het artikel, in de rangschikking volgens populariteit, is in de marge aangegeven; de populariteit (een schatting van het aantal bezoeken dat het artikel op een dag zal krijgen als het huidige ritme wordt aangehouden) en het aantal bezoeken sinds het het begin van de site staan in het vakje dat verschijnt als je met de muis over de titel van het artikel beweegt.',
	'texte_signification' => 'De donkere balkjes stellen alle samengetelde bezoeken weer (totaal van alle subrubrieken), de lichte balkjes het aantal bezoeken voor elke rubriek.',
	'titre_evolution_visite' => 'Evolutie van de bezoeken',
	'titre_liens_entrants' => 'Inkomende koppelingen',
	'titre_page_statistiques' => 'Statistieken per rubriek',
	'titre_page_statistiques_visites' => 'Statistieken van de bezoeken',

	// V
	'visites_journalieres' => 'Aantal bezoeken per dag',
	'visites_mensuelles' => 'Aantal maandelijkse bezoeken',
];
